==> 1.0.0.tar.gz: bin/dart_anticaptcha.dart <==
import 'dart:convert';
import 'dart:io' as Io;
import 'dart:async';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:http/retry.dart';

void main() async {
  AntiCaptcha anticaptcha = AntiCaptcha('581bad1f5705587b00407317b2d6f403');

  String img = 'https://api.vk.com/captcha.php?sid=605143621908&s=1';
  String? imgbase64 = await anticaptcha.networkImageToBase64(img);
  Map headers = {
    "clientKey": '581bad1f5705587b00407317b2d6f403',
    "task": {"type": "ImageToTextTask", "body": imgbase64}
  };
  dynamic result = await anticaptcha.returnResult(headers, imgbase64!);
  print(result);
}

class AntiCaptcha {
  String createTaskUrl = 'https://api.anti-captcha.com/createTask';
  String getTaskResultUrl = 'https://api.anti-captcha.com/getTaskResult';

  late String clientKey;
  AntiCaptcha(this.clientKey);

  returnResult(Map settingObject, String base64) async {
    final event = await _apiRequest(createTaskUrl, settingObject);
    final response = json.decode('$event');

    Map headers = {"clientKey": clientKey, "taskId": response['taskId']};
    while (true) {
      var res = await _apiRequest(getTaskResultUrl, headers);
      var result = await json.decode('$res');
      await Future.delayed(Duration(milliseconds: 100));
      if (result['status'] == 'processing') {
      } else {
        return result['solution']['text'];
      }
    }
  }

  Future<String?> memoryImageToBase64(String image) async {
    final bytes = Io.File(image).readAsBytesSync();
    return (bytes != null ? base64Encode(bytes) : null);
  }

  Future<String?> networkImageToBase64(String imageUrl) async {
    http.Response response = await http.get(Uri.parse(imageUrl));
    final bytes = response.bodyBytes;
    return (bytes != null ? base64Encode(bytes) : null);
  }

  Future<String?> _apiRequest(String url, Map jsonHeaders) async {
    HttpClient httpClient = new HttpClient();
    HttpClientRequest request = await httpClient.postUrl(Uri.parse(url));
    request.headers.set('content-type', 'application/json');
    request.add(utf8.encode(json.encode(jsonHeaders)));
    HttpClientResponse response = await request.close();
    String reply = await response.transform(utf8.decoder).join();
    httpClient.close();
    return reply;
  }
}

==> 1.0.4.tar.gz: bin/dart_anticaptcha.dart <==
import 'dart:convert';
import 'dart:io' as Io;
import 'dart:async';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:http/retry.dart';

void main() {
  AntiCaptcha antiCaptcha = AntiCaptcha('123');
}

class AntiCaptcha {
  String createTaskUrl = 'https://api.anti-captcha.com/createTask';
  String getTaskResultUrl = 'https://api.anti-captcha.com/getTaskResult';

  late String clientKey;
  AntiCaptcha(this.clientKey);

  returnResult(Map settingObject, String base64) async {
    final event = await _apiRequest(createTaskUrl, settingObject);
    final response = json.decode('$event');

    Map headers = {"clientKey": clientKey, "taskId": response['taskId']};
    while (true) {
      var res = await _apiRequest(getTaskResultUrl, headers);
      var result = await json.decode('$res');
      await Future.delayed(Duration(milliseconds: 100));
      if (result['status'] == 'processing') {
      } else {
        return result['solution']['text'];
      }
    }
  }

  Future<String?> memoryImageToBase64(String image) async {
    final bytes = Io.File(image).readAsBytesSync();
    return (bytes != null ? base64Encode(bytes) : null);
  }

  Future<String?> networkImageToBase64(String imageUrl) async {
    http.Response response = await http.get(Uri.parse(imageUrl));
    final bytes = response.bodyBytes;
    return (bytes != null ? base64Encode(bytes) : null);
  }

  Future<String?> _apiRequest(String url, Map jsonHeaders) async {
    HttpClient httpClient = new HttpClient();
    HttpClientRequest request = await httpClient.postUrl(Uri.parse(url));
    request.headers.set('content-type', 'application/json');
    request.add(utf8.encode(json.encode(jsonHeaders)));
    HttpClientResponse response = await request.close();
    String reply = await response.transform(utf8.decoder).join();
    httpClient.close();
    return reply;
  }
}
